# Thinc Webservice
Adds i18n and delta support for models to [django-restframework](http://www.django-rest-framework.org/)

## Requirements
- Django (1.8 or higher)
- djangorestframework (3.1 or higher)
- pytz (2014.10 or higher)
- django-grappelli (2.6.0 or higher)